@@ -9,7 +9,7 @@
 #
 package Dist::Zilla::PluginBundle::RSRCHBOY;
 {
-  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.020';
+  $Dist::Zilla::PluginBundle::RSRCHBOY::VERSION = '0.022';
 }
 
 # ABSTRACT: Zilla your distributions like RSRCHBOY!
@@ -71,10 +71,62 @@ use Pod::Coverage::TrustPod ( );
 has is_task    => (is => 'lazy', isa => 'Bool');
 has is_app     => (is => 'lazy', isa => 'Bool');
 has is_private => (is => 'lazy', isa => 'Bool');
+has rapid_dev  => (is => 'lazy', isa => 'Bool');
 
 sub _build_is_task    { $_[0]->payload->{task}                             }
 sub _build_is_app     { $_[0]->payload->{cat_app} || $_[0]->payload->{app} }
 sub _build_is_private { $_[0]->payload->{private}                          }
+sub _build_rapid_dev  { $_[0]->payload->{rapid_dev}                        }
+
+
+sub copy_from_build {
+    my ($self) = @_;
+
+    my @copy= qw{ LICENSE };
+    push @copy, 'Makefile.PL'
+        if $self->is_app;
+
+    return @copy;
+}
+
+
+sub release_plugins {
+
+    return (
+        qw{
+            UploadToCPAN
+            GitHub::Meta
+            CheckPrereqsIndexed
+        } ,
+        [ 'GitHub::Update' => { metacpan => 1 } ],
+        [ ArchiveRelease => {
+            directory => 'releases',
+        }],
+    );
+}
+
+
+sub author_tests {
+    my ($self) = @_;
+
+    return () if $self->rapid_dev;
+
+    return (
+        [ 'Test::PodSpelling' => { stopwords => [ $self->stopwords ] } ],
+        qw{
+            ConsistentVersionTest
+            PodCoverageTests
+            PodSyntaxTests
+            NoTabsTests
+            EOLTests
+            HasVersionTests
+            Test::Compile
+            Test::Portability
+            ExtraTests
+            NoSmartCommentsTests
+        },
+    );
+}
 
 
 sub configure {
@@ -83,15 +135,6 @@ sub configure {
     my $autoprereq_opts = $self->config_slice({ autoprereqs_skip => 'skip' });
     my $prepender_opts  = $self->config_slice({ prepender_skip   => 'skip' });
 
-    my @private_or_public
-        = $self->is_private
-        ? ()
-        : (
-            qw{ UploadToCPAN GitHub::Meta } ,
-            [ 'GitHub::Update' => { metacpan => 1 } ],
-        )
-        ;
-
     # if we have a weaver.ini, use that; otherwise use our bundle
     my $podweaver
         = file('weaver.ini')->stat
@@ -102,7 +145,7 @@ sub configure {
     $self->add_plugins(qw{ NextRelease });
 
     $self->add_bundle(Git => {
-        allow_dirty => [ qw{ dist.ini weaver.ini README.pod Changes } ],
+        allow_dirty => [ qw{ .gitignore LICENSE dist.ini weaver.ini README.pod Changes } ],
         tag_format  => '%v',
     });
 
@@ -129,42 +172,27 @@ sub configure {
         },
         [ AutoPrereqs => $autoprereq_opts ],
         [ Prepender   => $prepender_opts  ],
-        [ 'Test::PodSpelling' => { stopwords => [ $self->stopwords ] } ],
-        qw{
 
-            ConsistentVersionTest
-            PodCoverageTests
-            PodSyntaxTests
-            NoTabsTests
-            EOLTests
-            HasVersionTests
-            Test::Compile
-            Test::Portability
-            ExtraTests
+        $self->author_tests,
+
+        qw{
             MinimumPerl
             ReportVersions::Tiny
-            NoSmartCommentsTests
 
             MetaConfig
             MetaJSON
             MetaYAML
 
             TestRelease
-            CheckPrereqsIndexed
             ConfirmRelease
         },
 
-        @private_or_public,
+        $self->release_plugins,
 
         ($self->is_task ? 'TaskWeaver' : $podweaver),
 
-        ($self->is_app ?
-            (
-               [ PruneFiles         => { filenames => 'Makefile.PL' } ],
-               [ CopyFilesFromBuild => { copy      => 'Makefile.PL' } ],
-            )
-            : ()
-        ),
+        [ PruneFiles => { filenames => [ $self->copy_from_build ] } ],
+        [ CopyFilesFromBuild => { copy => [ $self->copy_from_build ] } ],
 
         [ ReadmeAnyFromPod  => ReadmePodInRoot => {
             type     => 'pod',
@@ -172,10 +200,6 @@ sub configure {
             location => 'root',
         }],
 
-        [ ArchiveRelease => {
-            directory => 'releases',
-        }],
-
         [ InstallRelease => {
             install_command => 'cpanm .',
         }],
@@ -211,13 +235,15 @@ __PACKAGE__->meta->make_immutable;
 
 =encoding utf-8
 
+=for :stopwords Chris Weyl
+
 =head1 NAME
 
 Dist::Zilla::PluginBundle::RSRCHBOY - Zilla your distributions like RSRCHBOY!
 
 =head1 VERSION
 
-This document describes version 0.020 of Dist::Zilla::PluginBundle::RSRCHBOY - released May 02, 2012 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
+This document describes version 0.022 of Dist::Zilla::PluginBundle::RSRCHBOY - released June 06, 2012 as part of Dist-Zilla-PluginBundle-RSRCHBOY.
 
 =head1 SYNOPSIS
 
@@ -232,6 +258,16 @@ this being too terribly consistent/sane until the version gets to 1.
 
 =head1 METHODS
 
+=head2 copy_from_build
+
+Returns a list of files that, once built, will be copied back into the root.
+
+=head2 release_plugins
+
+Plugin configuration for public release.
+
+=head2 author_tests
+
 =head2 configure
 
 Preps plugin lists / config; see L<Dist::Zilla::Role::PluginBundle::Easy>.
